#[repr(u8)]pub enum BaseaddrSwitchSel {
BASEADDR_SWITCH_SEL_0 = 0,
BASEADDR_SWITCH_SEL_1 = 1,
}Variants
BASEADDR_SWITCH_SEL_0 = 0
Switching base address at the edge of the vsync
BASEADDR_SWITCH_SEL_1 = 1
Switching base address at the edge of the first data of each frame
Implementations