#[repr(u8)]pub enum MaskOption {
MASK_OPTION_0 = 0,
MASK_OPTION_1 = 1,
MASK_OPTION_2 = 2,
MASK_OPTION_3 = 3,
}Variants
MASK_OPTION_0 = 0
Writing to memory (OCRAM or external DDR) from first completely frame, when using this option, the CSI_ENABLE should be 1.
MASK_OPTION_1 = 1
Writing to memory when CSI_ENABLE is 1.
MASK_OPTION_2 = 2
Writing to memory from second completely frame, when using this option, the CSI_ENABLE should be 1.
MASK_OPTION_3 = 3
Writing to memory when data comes in, not matter the CSI_ENABLE is 1 or 0.
Implementations
Sourceimpl MaskOption
impl MaskOption