#[repr(u8)]pub enum Redge {
REDGE_0 = 0,
REDGE_1 = 1,
}Variants
REDGE_0 = 0
Pixel data is latched at the falling edge of CSI_PIXCLK
REDGE_1 = 1
Pixel data is latched at the rising edge of CSI_PIXCLK
Implementations